@@ -6,8 +6,6 @@ import pathlib
 import sys
 import uuid
 
-from ..folder import Folder
-
 def findFolder():
 	'''
 	Find the Hateno-compatible folder we're currently in by testing the existence of the `.hateno` subfolder.
@@ -15,22 +13,18 @@ def findFolder():
 
 	Returns
 	-------
-	folder : Folder
-		Folder instance corresponding to the found path. `None` if nothing has been found.
+	folder : pathlib.Path
+		Path to the folder, relatively to the current one. `None` if nothing has been found.
 	'''
 
 	folder = pathlib.Path('.').resolve()
 
-	try:
-		return Folder(folder)
+	if (folder / '.hateno').is_dir():
+		return folder
 
-	except FileNotFoundError:
-		for parent in folder.parents:
-			try:
-				return Folder(parent)
-
-			except FileNotFoundError:
-				pass
+	for parent in folder.parents:
+		if (parent / '.hateno').is_dir():
+			return parent
 
 	return None
 
